package com.ruoyi.project.configuration.controller;

import java.util.List;

import com.ruoyi.project.configuration.domain.TMatterProtect;
import com.ruoyi.project.configuration.service.ITMatterProtectService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.framework.aspectj.lang.annotation.Log;
import com.ruoyi.framework.aspectj.lang.enums.BusinessType;
import com.ruoyi.framework.web.controller.BaseController;
import com.ruoyi.framework.web.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.framework.web.page.TableDataInfo;

/**
 * 危害物质-防护用品Controller
 *
 * @author ruoyi
 * @date 2021-12-28
 */
@RestController
@RequestMapping("/configuration/protect")
public class TMatterProtectController extends BaseController {

    @Autowired
    private ITMatterProtectService tMatterProtectService;

    /**
     * 查询危害物质-防护用品列表
     */
    @PreAuthorize("@ss.hasPermi('configuration:protect:list')")
    @GetMapping("/list")
    public TableDataInfo list(TMatterProtect tMatterProtect) {
        startPage();
        List<TMatterProtect> list = tMatterProtectService.selectTMatterProtectList(tMatterProtect);
        return getDataTable(list);
    }

    /**
     * 查询危害物质-防护用品列表
     */
    @GetMapping("/type")
    public AjaxResult type(TMatterProtect tMatterProtect) {
        return AjaxResult.success(tMatterProtectService.selectTMatterProtectList(tMatterProtect));
    }

    /**
     * 导出危害物质-防护用品列表
     */
    @PreAuthorize("@ss.hasPermi('configuration:protect:export')")
    @Log(title = "危害物质-防护用品", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(TMatterProtect tMatterProtect) {
        List<TMatterProtect> list = tMatterProtectService.selectTMatterProtectList(tMatterProtect);
        ExcelUtil<TMatterProtect> util = new ExcelUtil<TMatterProtect>(TMatterProtect.class);
        return util.exportExcel(list, "protect");
    }

    /**
     * 获取危害物质-防护用品详细信息
     */
    @PreAuthorize("@ss.hasPermi('configuration:protect:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return AjaxResult.success(tMatterProtectService.selectTMatterProtectById(id));
    }

    /**
     * 新增危害物质-防护用品
     */
    @PreAuthorize("@ss.hasPermi('configuration:protect:add')")
    @Log(title = "危害物质-防护用品", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TMatterProtect tMatterProtect) {
        return toAjax(tMatterProtectService.insertTMatterProtect(tMatterProtect));
    }

    /**
     * 修改危害物质-防护用品
     */
    @PreAuthorize("@ss.hasPermi('configuration:protect:edit')")
    @Log(title = "危害物质-防护用品", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TMatterProtect tMatterProtect) {
        return toAjax(tMatterProtectService.updateTMatterProtect(tMatterProtect));
    }

    /**
     * 删除危害物质-防护用品
     */
    @PreAuthorize("@ss.hasPermi('configuration:protect:remove')")
    @Log(title = "危害物质-防护用品", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tMatterProtectService.deleteTMatterProtectByIds(ids));
    }
}
